import { createWebHashHistory, createRouter } from 'vue-router'

import Layout from '@/layout/index.vue'

// 主页路由
import HomeIndex from '@/views/home/index.vue'
import HomeView from '@/views/home/home.vue'
import TodoView from '@/views/home/todo.vue'
import StartView from '@/views/home/start.vue'

// 登录页
import LoginView from '@/views/login/index.vue'

// 资产业务
import AssetsIndex from '@/views/assets/index.vue'
import AssetsTodoDetailView from '@/views/assets/todoDetail.vue'
import AssetsPlaceOrderView from '@/views/assets/placeOrder.vue'
import AssetsMyOrder from '@/views/assets/myOrder.vue'
import AssetsDetail from '@/views/assets/detail.vue'
import AssetsPendingOrder from '@/views/assets/pendingOrder.vue'

// 个贷业务
import PersonalIndex from '@/views/personal/index.vue'
import PersonalTodoDetailView from '@/views/personal/todoDetail.vue'
import PersonalPlaceOrderView from '@/views/personal/placeOrder.vue'
import PersonalMyOrder from '@/views/personal/myOrder.vue'
import PersonalDetail from '@/views/personal/detail.vue'
import PersonalPendingOrder from '@/views/personal/pendingOrder.vue'
import PersonalDoneList from '@/views/personal/doneList.vue'

// 大中型业务
import MajorIndex from '@/views/major/index.vue'
import MajorTodoDetailView from '@/views/major/todoDetail.vue'
import MajorPlaceOrder from '@/views/major/placeOrder.vue'
import MajorMyOrder from '@/views/major/myOrder.vue'
import MajorDetail from '@/views/major/detail.vue'
import MajorPendingOrder from '@/views/major/pendingOrder.vue'

// 土规业务
import LandIndex from '@/views/land/index.vue'
import LandPlaceOrder from '@/views/land/placeOrder.vue'
import LandMyOrder from '@/views/land/myOrder.vue'
import LandPendingOrder from '@/views/land/pendingOrder.vue'

const routes = [
  // 重定向到首页的路由
  {
    path:'/',
    redirect:'/index/home/index'
  },
  {
    path:'/index',
    redirect:'/index/home/index'
  },
  {
    path:'/index/home',
    redirect:'/index/home/index'
  },
  // 路由页面配置
  {
    path: '/index',
    component: Layout,
    name: 'index',
    children: [
      {
        // 首页配置
        path: 'home',
        component: HomeIndex,
        name: 'homeIndex',
        children: [
          {
            path: 'index',
            component: HomeView,
            name: 'homeView',
            meta: {
              title: '首页'
            },
          },
          {
            path: 'todo',
            component: TodoView,
            name: 'todoView',
            meta: {
              title: '待办'
            },
          },
          {
            path: 'start',
            component: StartView,
            name: 'startView',
            meta: {
              title: '快速发起'
            },
          },
        ]
      },
      // 登录页
      {
        path: 'login',
        component: LoginView,
        name: 'loginIndex',
      },
      // 资产业务
      {
        path: 'assets',
        component: AssetsIndex,
        name: 'assetsView',
        children: [
          {
            path: 'todoDetail',
            component: AssetsTodoDetailView,
            name: 'assetsTodoDetailView',
            meta: {
              title: '待办处理-资产'
            },
          },
          {
            path: 'placeOrder',
            component: AssetsPlaceOrderView,
            name: 'assetsPlaceOrderView',
            meta: {
              title: '资产业务下单'
            },
          },
          {
            path: 'myOrder',
            component: AssetsMyOrder,
            name: 'assetsMyOrderView',
            meta: {
              title: '我的订单-资产'
            },
          },
          {
            path: 'detail',
            component: AssetsDetail,
            name: 'assetsDetailView',
            meta: {
              title: '我的订单-资产'
            },
          },
          {
            path: 'pendingOrder',
            component: AssetsPendingOrder,
            name: 'assetsPendingOrderView',
            meta: {
              title: '正在进行-资产'
            },
          },
        ]
      },
      // 个贷业务
      {
        path: 'personal',
        component: PersonalIndex,
        name: 'personalView',
        children: [
          {
            path: 'todoDetail',
            component: PersonalTodoDetailView,
            name: 'personalTodoDetailView',
            meta: {
              title: '待办处理-个贷'
            },
          },
          {
            path: 'placeOrder',
            component: PersonalPlaceOrderView,
            name: 'personalPlaceOrder',
            meta: {
              title: '个贷业务下单'
            },
          },
          {
            path: 'myOrder',
            component: PersonalMyOrder,
            name: 'personalMyOrderView',
            meta: {
              title: '我的订单-个贷'
            },
          },
          {
            path: 'detail',
            component: PersonalDetail,
            name: 'personalDetailView',
            meta: {
              title: '订单详情-资产'
            },
          },
          {
            path: 'pendingOrder',
            component: PersonalPendingOrder,
            name: 'personalPendingOrderView',
            meta: {
              title: '正在进行-个贷'
            },
          },
          {
            path: 'doneList',
            component: PersonalDoneList,
            name: 'personalDoneListView',
            meta: {
              title: '已办任务-个贷'
            },
          },
        ]
      },
      // 大中型业务
      {
        path: 'major',
        component: MajorIndex,
        name: 'majorView',
        children: [
          {
            path: 'todoDetail',
            component: MajorTodoDetailView,
            name: 'majorTodoDetailView',
            meta: {
              title: '待办处理-大中型'
            },
          },
          {
            path: 'placeOrder',
            component: MajorPlaceOrder,
            name: 'majorPlaceOrder',
            meta: {
              title: '大中型业务下单'
            },
          },
          {
            path: 'myOrder',
            component: MajorMyOrder,
            name: 'majorMyOrderView',
            meta: {
              title: '我的订单-大中型'
            },
          },
          {
            path: 'detail',
            component: MajorDetail,
            name: 'majorDetailView',
            meta: {
              title: '订单详情-大中型'
            },
          },
          {
            path: 'pendingOrder',
            component: MajorPendingOrder,
            name: 'majorPendingOrderView',
            meta: {
              title: '正在进行-大中型'
            },
          },
        ]
      },
      // 土规业务
      {
        path: 'land',
        component: LandIndex,
        name: 'landView',
        children: [
          {
            path: 'placeOrder',
            component: LandPlaceOrder,
            name: 'landPlaceOrder',
            meta: {
              title: '土规业务下单'
            },
          },
          {
            path: 'myOrder',
            component: LandMyOrder,
            name: 'landMyOrder',
            meta: {
              title: '我的订单-土规'
            },
          },
          {
            path: 'pendingOrder',
            component: LandPendingOrder,
            name: 'landPendingOrderView',
            meta: {
              title: '项目列表-土规'
            },
          },
        ]
      }
    ]
  },
]

const router = createRouter({
  history: createWebHashHistory(),
  routes,
})

export default router