import axios from 'axios'
import { getToken, removeToken } from '@/utils/auth'
import { showNotify } from 'vant';
import $router from '@/router'

// create an axios instance
const service = axios.create({
  // Vite默认不支持process
  // baseURL: process.env.VITE_BASE_URL,
  baseURL: import.meta.env.VITE_BASE_URL,
  timeout: 50000 // 请求超时
})

// 请求拦截器
service.interceptors.request.use(
  config => {
    if (getToken()) {
      // 设置请求带上token
      config.headers['token'] = getToken()
    }
    return config
  },
  error => {
    // 异常情况
    console.log(error)
    return Promise.reject(error)
  }
)

// 返回拦截器
service.interceptors.response.use(

  response => {
    const res = response.data

    // code不等于200的处理
    if (res.code !== 200) {
      // code 10004 未登录处理
      if (res.code === 10004 || res.code === 10005 || res.code === 10008) {
        showNotify(
          {
            type: 'danger',
            message: res.msg
          }
        );
        $router.push('/index/login');
        removeToken();
      } else if(res.code === 10033) { // code 10033 流程节点任务未完成处理
        showNotify(
          {
            type: 'danger',
            message: res.msg
          }
        );
      } else {
        showNotify(
          {
            type: 'danger',
            message: res.msg
          }
        );
      }
      return res
    } else {
      return res
    }
  },
  error => {
    console.log('err' + error)
    showNotify({ type: 'danger', message: error.message });
    return Promise.reject(error)
  }
)

export default service
